==> opencascade-7.4.0.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/opencascade/OpenCASCADECompileDefinitionsAndFlags-release.cmake <==
#-----------------------------------------------------------------------------
#
# OpenCASCADECompileDefinitionsAndFlags-release.cmake - OpenCASCADE CMake file 
# with compile definitions and C/C++ flags for Release configuration.
#
# This file is configured by OpenCASCADE.
#

# The C and C++ flags added by OpenCASCADE to the cmake-configured flags.
set (OpenCASCADE_C_FLAGS_RELEASE      "-O3 -DNDEBUG -s -DNo_Exception")
set (OpenCASCADE_CXX_FLAGS_RELEASE    "-O3 -DNDEBUG -s -DNo_Exception")

# The compile definitions used by OpenCASCADE.
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_VTK>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkDomainsChemistry_AUTOINIT=2\(vtkDomainsChemistryOpenGL2,vtkDomainsParallelChemistry\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkFiltersCore_AUTOINIT=1\(vtkFiltersParallelDIY2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkFiltersFlowPaths_AUTOINIT=1\(vtkFiltersParallelFlowPaths\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkFiltersParallel_AUTOINIT=2\(vtkFiltersParallelDIY2,vtkFiltersParallelGeometry\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOExodus_AUTOINIT=1\(vtkIOParallelExodus\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOExport_AUTOINIT=2\(vtkIOExportOpenGL2,vtkIOExportPDF\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOGeometry_AUTOINIT=1\(vtkIOMPIParallel\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOImage_AUTOINIT=1\(vtkIOMPIImage\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOParallel_AUTOINIT=1\(vtkIOMPIParallel\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOSQL_AUTOINIT=2\(vtkIOMySQL,vtkIOPostgreSQL\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOXdmf3_AUTOINIT=1\(vtkIOParallelXdmf3\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingContext2D_AUTOINIT=1\(vtkRenderingContextOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingCore_AUTOINIT=3\(vtkInteractionStyle,vtkRenderingFreeType,vtkRenderingOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingFreeType_AUTOINIT=2\(vtkRenderingFreeTypeFontConfig,vtkRenderingMatplotlib\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingLICOpenGL2_AUTOINIT=1\(vtkRenderingParallelLIC\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingOpenGL2_AUTOINIT=1\(vtkRenderingGL2PSOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingVolume_AUTOINIT=1\(vtkRenderingVolumeOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_FREEIMAGE>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_FFMPEG>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_TBB>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:VTK_OPENGL2_BACKEND>)

==> opencascade-7.5.0-2-x86_64.pkg.tar.zst: usr/lib/cmake/opencascade/OpenCASCADECompileDefinitionsAndFlags-release.cmake <==
#-----------------------------------------------------------------------------
#
# OpenCASCADECompileDefinitionsAndFlags-release.cmake - OpenCASCADE CMake file 
# with compile definitions and C/C++ flags for Release configuration.
#
# This file is configured by OpenCASCADE.
#

# The C and C++ flags added by OpenCASCADE to the cmake-configured flags.
set (OpenCASCADE_C_FLAGS_RELEASE      "-O3 -DNDEBUG -s")
set (OpenCASCADE_CXX_FLAGS_RELEASE    "-O3 -DNDEBUG -s")

# The compile definitions used by OpenCASCADE.
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_VTK>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkDomainsChemistry_AUTOINIT=2\(vtkDomainsChemistryOpenGL2,vtkDomainsParallelChemistry\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkFiltersCore_AUTOINIT=1\(vtkFiltersParallelDIY2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkFiltersFlowPaths_AUTOINIT=1\(vtkFiltersParallelFlowPaths\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkFiltersParallel_AUTOINIT=2\(vtkFiltersParallelDIY2,vtkFiltersParallelGeometry\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOExodus_AUTOINIT=1\(vtkIOParallelExodus\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOExport_AUTOINIT=2\(vtkIOExportOpenGL2,vtkIOExportPDF\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOGeometry_AUTOINIT=1\(vtkIOMPIParallel\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOImage_AUTOINIT=1\(vtkIOMPIImage\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOParallel_AUTOINIT=1\(vtkIOMPIParallel\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOSQL_AUTOINIT=2\(vtkIOMySQL,vtkIOPostgreSQL\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkIOXdmf3_AUTOINIT=1\(vtkIOParallelXdmf3\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingContext2D_AUTOINIT=1\(vtkRenderingContextOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingCore_AUTOINIT=3\(vtkInteractionStyle,vtkRenderingFreeType,vtkRenderingOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingFreeType_AUTOINIT=2\(vtkRenderingFreeTypeFontConfig,vtkRenderingMatplotlib\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingLICOpenGL2_AUTOINIT=1\(vtkRenderingParallelLIC\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingOpenGL2_AUTOINIT=1\(vtkRenderingGL2PSOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:vtkRenderingVolume_AUTOINIT=1\(vtkRenderingVolumeOpenGL2\)>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_FREEIMAGE>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_FFMPEG>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:HAVE_TBB>)
set_property(DIRECTORY APPEND PROPERTY COMPILE_DEFINITIONS $<$<CONFIG:Release>:VTK_OPENGL2_BACKEND>)
